==> haskell-fsnotify-0.3.0.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-9w1afbDXu9gJyqo4Y7JhIN
key: fsnotify-0.3.0.1-9w1afbDXu9gJyqo4Y7JhIN
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 49f8fb0d6eee5dec491214ed0dcdcbeb
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-9w1afbDXu9gJyqo4Y7JhIN
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-IVJAqwrZqPyE1P4XFARbnM unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=fc69dbbaf4b44ed9f384fa81491b5636
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=ab9a7ffd21f0ec5d7d17bb8be4fa9bb3
             shelly-1.8.1-IVJAqwrZqPyE1P4XFARbnM=9c79ebfe25ee51281599de821b34a7ff
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.3.0.1
id: fsnotify-0.3.0.1-FWPfjqde2l8FUzW8Py0zT
key: fsnotify-0.3.0.1-FWPfjqde2l8FUzW8Py0zT
license: BSD-3-Clause
maintainer: Tom McLaughlin <tom@codedown.io>
author: Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
abi: 54041e2c2db9ce35ad65ea24935cf14b
exposed: True
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fsnotify-0.3.0.1
hs-libraries: HSfsnotify-0.3.0.1-FWPfjqde2l8FUzW8Py0zT
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5 filepath-1.4.2 text-1.2.3.0 time-1.8.0.2
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi
    shelly-1.8.1-KiPHAtIzfowL8U2zaWYmzK unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=fc69dbbaf4b44ed9f384fa81491b5636
             hinotify-0.3.10-1hds7Zybs3sLhehpuSG4Xi=ab9a7ffd21f0ec5d7d17bb8be4fa9bb3
             shelly-1.8.1-KiPHAtIzfowL8U2zaWYmzK=41af39b3ed12c91974536183c35a5aaa
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
